userFlaviencancel
reporust_rebootcancel

8,148 Commits over 1,004 Days - 0.34cph!

14 Days Ago
Conveyors are poolable We prewarm 10 copies
14 Days Ago
We now prefill our pool with up to 30 copies of the most used io entities. The first time you load a big base will be a tad faster at the expense of more upfront memory You're going to load them as soon as you load the local zerg base anyway
14 Days Ago
Added SoundPlayerCull to industrial conveyors looping hum sound. It was spawned regardless of distance then paused Editor profiling, 30 conveyors spawned 150m away: - 9ms -> 2.3ms total - ~470us -> ~220us per conveyor spawn - Sound.DoUpdate per frame: 112us -> 20us (the 30 paused hums were still updated every frame)
14 Days Ago
Removed the pref to skip unity event listener baking in editor, wasn't necessary (renamed the branch to entityspawning_optims)
14 Days Ago
Added entity/item autocompletion to more commands
14 Days Ago
spawngrid and teleportany autocomplete entity names
14 Days Ago
merge from console_autocomplete_improvements
14 Days Ago
Optimized entities with flag toggles spawning: EntityFlag_Toggle now bakes its listeners at prefab preprocessing and calls them directly instead of invoking its UnityEvent The first UnityEvent invoke on every new instance looked its listeners up by reflection. Rough profiling from the editor, loading in a mix of 248 entities (io, locks, doors and some random deployables) EntityFlag.DoUpdate 26ms -> 2ms total ~100us -> ~9us per entity ~940 KB -> ~231 KB total
14 Days Ago
merge from map_optims
14 Days Ago
Fixed deep sea layer nuking all the monument markers Fixed shop markers cache being filled with junk when disconnecting/reconnecting
15 Days Ago
merge from quickcraft_optims
15 Days Ago
Optimized prefab lookups by path, we now cache exact spelling hits. Makes each FindPrefab ~7x faster on repeat calls (was around 6us per call in builds, up to 0.5ms in frames that spawn a lot when entering network range of a base) We could make prefab paths case sensitive instead, but I'm not gonna change the million callers and that could break plugins
15 Days Ago
Fixed QuickCraft.FindItems spending ~2ms checking if you own a dlc after looting an item, SteamDownloadableContent now caches the answer for each DLC
15 Days Ago
merge from teamui_optims
15 Days Ago
Fixed the player name cache being cleared on every team update, causing the team UI to refilter every name through Steam (~1.5ms every 4s with 7 teammates)
15 Days Ago
merge from animalanimation_optims
15 Days Ago
Fixed AnimalAnimation out of range errors
15 Days Ago
merge from notices_rtl_fix
15 Days Ago
Fixed item dropped and item pickup notices not working with RTL languages
15 Days Ago
Fixed CraftingNotice allocating every frame when crafting an item Also converted them to RustText so they can display RTL languages
15 Days Ago
merge from boateffects_optims
15 Days Ago
Optimized MotorRowboat.Update, it has a slow water height check for its effects, around 0.10ms - culled by distance - skipped when stationnary for >3s
15 Days Ago
Fixed AnimalAnimation allocating 80 bytes for each footstep
15 Days Ago
merge from animalanimation_optims
15 Days Ago
▊▉▉▋▋▋█ ▉ ▋▌▍ ▇▉▌▇▊▌ ▄▅ ▆▍▋▉ ▉▉▄▆▊▊▅ ▌▄ ▋█▋ ▊▆▋▋▄▉▇▋ ▄▄▌▅▌▄▍▆▆▌▅▊▍▍▍▆ ▋ ▉▌▍▉▍▍▉▄ ▅ ▋█▅▇▄▊▊▍ ██▋▍█▊ ▋▍▉▅▊▌▋▊▆▉▄▉▋█▆▄▅▆▄▊▇█▅▍▋█▍▄▉▉▉▋▄▅▆▉█▋▍▆█▄▆▉▆▉▍▅▋▇▇█▌▋▆▆▌▊█▅▌▋▄▊
15 Days Ago
merge from texturestreaming_texturepropertiescache_fix
15 Days Ago
Fixed TextureStreaming never filling its shader texture property cache, every belt swap was allocating all shader property names (18KB down to 1KB per swap)
15 Days Ago
merge from lightlod_optims
15 Days Ago
Cache DistanceFlareLOD fading action
15 Days Ago
Fixed shadowlights convar handler stacking up across editor play sessions
15 Days Ago
Fixed LightLOD.Awake and OnDestroy allocating The shadow caching convar callback was subscribed per light, every light spawn and destroy copied the whole handler list (had 1500 lights, 10KB every time)
15 Days Ago
Cache AmbientLightLOD fading action
15 Days Ago
merge from drinkingpoint_optims
15 Days Ago
merge from drinkingpoint_optims
15 Days Ago
Fixed UpdateWaterDrinkingPoint running when not needed: - now runs in the entity looking at tick every 0.1s - skipped when mounted, or when move speed is above drinkMovementSpeed Its a trace so it wasnt scaling well in big bases
15 Days Ago
merge from map_optims
15 Days Ago
Cache vending machines and skip rebuilding all their markers when opening the map Saves around 80ms on a server with 170 vending machines
15 Days Ago
merge from console_autocomplete_improvements
15 Days Ago
merge from lookatboat_optim
15 Days Ago
Cache LandmarkInfos so we only rebuild them when necessary
15 Days Ago
When opening the map, only rebuild the mission provider states when they changed, saves ~100ms when opening the map on my machine
15 Days Ago
Cache LookAtBoatBuildingBlock action so it doesnt allocate every frame
15 Days Ago
Added a log in the console when you're trying to connect to a server with Disable Game UI enabled
15 Days Ago
InvokeHandler use cached method name for profiler samples, stops ~1KB/frame of string allocs in debug builds
18 Days Ago
Gun tests
18 Days Ago
Run is cancelled when the client is disconnected Client can use fixture convars More client base combat entity tests
18 Days Ago
Client tests are added to the CI test list
18 Days Ago
Fixed a bunch of failing tests
18 Days Ago
█▉▉▌▅▉▌▅ ▉▄▊▌ ▌▇▅▇▌▍
18 Days Ago
Cleaned up test ores Added client test spawning all base combat entity and looking for errors